package com.mysql.jdbc.jdbc2.optional;

import com.mysql.jdbc.ConnectionImpl;
import com.mysql.jdbc.SQLError;
import com.mysql.jdbc.Util;
import java.lang.reflect.Constructor;
import java.sql.CallableStatement;
import java.sql.Connection;
import java.sql.DatabaseMetaData;
import java.sql.PreparedStatement;
import java.sql.SQLException;
import java.sql.SQLWarning;
import java.sql.Savepoint;
import java.sql.Statement;
import java.util.Map;

/* loaded from: com_mysql_jdbc_jdbc2_optional.jar:com/mysql/jdbc/jdbc2/optional/ConnectionWrapper.class */
public class ConnectionWrapper extends WrapperBase implements Connection {
    protected ConnectionImpl mc;
    private MysqlPooledConnection mpc;
    private String invalidHandleStr = "Logical handle no longer valid";
    private boolean closed = false;
    private boolean isForXa;
    private static final Constructor JDBC_4_CONNECTION_WRAPPER_CTOR;
    static Class class$com$mysql$jdbc$jdbc2$optional$MysqlPooledConnection;
    static Class class$com$mysql$jdbc$ConnectionImpl;

    static {
        Class<?> cls;
        Class<?> cls2;
        if (Util.isJdbc4()) {
            try {
                Class<?> cls3 = Class.forName("com.mysql.jdbc.jdbc2.optional.JDBC4ConnectionWrapper");
                Class<?>[] clsArr = new Class[3];
                if (class$com$mysql$jdbc$jdbc2$optional$MysqlPooledConnection == null) {
                    cls = class$("com.mysql.jdbc.jdbc2.optional.MysqlPooledConnection");
                    class$com$mysql$jdbc$jdbc2$optional$MysqlPooledConnection = cls;
                } else {
                    cls = class$com$mysql$jdbc$jdbc2$optional$MysqlPooledConnection;
                }
                clsArr[0] = cls;
                if (class$com$mysql$jdbc$ConnectionImpl == null) {
                    cls2 = class$("com.mysql.jdbc.ConnectionImpl");
                    class$com$mysql$jdbc$ConnectionImpl = cls2;
                } else {
                    cls2 = class$com$mysql$jdbc$ConnectionImpl;
                }
                clsArr[1] = cls2;
                clsArr[2] = Boolean.TYPE;
                JDBC_4_CONNECTION_WRAPPER_CTOR = cls3.getConstructor(clsArr);
                return;
            } catch (ClassNotFoundException e) {
                throw new RuntimeException(e);
            } catch (NoSuchMethodException e2) {
                throw new RuntimeException(e2);
            } catch (SecurityException e3) {
                throw new RuntimeException(e3);
            }
        }
        JDBC_4_CONNECTION_WRAPPER_CTOR = null;
    }

    static Class class$(String x0) {
        try {
            return Class.forName(x0);
        } catch (ClassNotFoundException x1) {
            throw new NoClassDefFoundError(x1.getMessage());
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public static ConnectionWrapper getInstance(MysqlPooledConnection mysqlPooledConnection, ConnectionImpl mysqlConnection, boolean forXa) throws SQLException {
        return !Util.isJdbc4() ? new ConnectionWrapper(mysqlPooledConnection, mysqlConnection, forXa) : (ConnectionWrapper) Util.handleNewInstance(JDBC_4_CONNECTION_WRAPPER_CTOR, new Object[]{mysqlPooledConnection, mysqlConnection, Boolean.valueOf(forXa)});
    }

    public ConnectionWrapper(MysqlPooledConnection mysqlPooledConnection, ConnectionImpl mysqlConnection, boolean forXa) throws SQLException {
        this.mc = null;
        this.mpc = null;
        this.mpc = mysqlPooledConnection;
        this.mc = mysqlConnection;
        this.pooledConnection = this.mpc;
        this.isForXa = forXa;
        if (this.isForXa) {
            setInGlobalTx(false);
            setAutoCommit(false);
        }
    }

    @Override // java.sql.Connection
    public void setAutoCommit(boolean autoCommit) throws SQLException {
        checkClosed();
        if (autoCommit && isInGlobalTx()) {
            throw SQLError.createSQLException("Can't set autocommit to 'true' on an XAConnection", "2D000", 1401);
        }
        try {
            this.mc.setAutoCommit(autoCommit);
        } catch (SQLException sqlException) {
            checkAndFireConnectionError(sqlException);
        }
    }

    @Override // java.sql.Connection
    public boolean getAutoCommit() throws SQLException {
        checkClosed();
        try {
            return this.mc.getAutoCommit();
        } catch (SQLException sqlException) {
            checkAndFireConnectionError(sqlException);
            return false;
        }
    }

    @Override // java.sql.Connection
    public void setCatalog(String catalog) throws SQLException {
        checkClosed();
        try {
            this.mc.setCatalog(catalog);
        } catch (SQLException sqlException) {
            checkAndFireConnectionError(sqlException);
        }
    }

    @Override // java.sql.Connection
    public String getCatalog() throws SQLException {
        checkClosed();
        try {
            return this.mc.getCatalog();
        } catch (SQLException sqlException) {
            checkAndFireConnectionError(sqlException);
            return null;
        }
    }

    @Override // java.sql.Connection
    public boolean isClosed() throws SQLException {
        return this.closed || this.mc.isClosed();
    }

    public boolean isMasterConnection() throws SQLException {
        return this.mc.isMasterConnection();
    }

    @Override // java.sql.Connection
    public void setHoldability(int arg0) throws SQLException {
        checkClosed();
        try {
            this.mc.setHoldability(arg0);
        } catch (SQLException sqlException) {
            checkAndFireConnectionError(sqlException);
        }
    }

    @Override // java.sql.Connection
    public int getHoldability() throws SQLException {
        checkClosed();
        try {
            return this.mc.getHoldability();
        } catch (SQLException sqlException) {
            checkAndFireConnectionError(sqlException);
            return 1;
        }
    }

    public long getIdleFor() {
        return this.mc.getIdleFor();
    }

    @Override // java.sql.Connection
    public DatabaseMetaData getMetaData() throws SQLException {
        checkClosed();
        try {
            return this.mc.getMetaData();
        } catch (SQLException sqlException) {
            checkAndFireConnectionError(sqlException);
            return null;
        }
    }

    @Override // java.sql.Connection
    public void setReadOnly(boolean readOnly) throws SQLException {
        checkClosed();
        try {
            this.mc.setReadOnly(readOnly);
        } catch (SQLException sqlException) {
            checkAndFireConnectionError(sqlException);
        }
    }

    @Override // java.sql.Connection
    public boolean isReadOnly() throws SQLException {
        checkClosed();
        try {
            return this.mc.isReadOnly();
        } catch (SQLException sqlException) {
            checkAndFireConnectionError(sqlException);
            return false;
        }
    }

    @Override // java.sql.Connection
    public Savepoint setSavepoint() throws SQLException {
        checkClosed();
        if (isInGlobalTx()) {
            throw SQLError.createSQLException("Can't set autocommit to 'true' on an XAConnection", "2D000", 1401);
        }
        try {
            return this.mc.setSavepoint();
        } catch (SQLException sqlException) {
            checkAndFireConnectionError(sqlException);
            return null;
        }
    }

    @Override // java.sql.Connection
    public Savepoint setSavepoint(String arg0) throws SQLException {
        checkClosed();
        if (isInGlobalTx()) {
            throw SQLError.createSQLException("Can't set autocommit to 'true' on an XAConnection", "2D000", 1401);
        }
        try {
            return this.mc.setSavepoint(arg0);
        } catch (SQLException sqlException) {
            checkAndFireConnectionError(sqlException);
            return null;
        }
    }

    @Override // java.sql.Connection
    public void setTransactionIsolation(int level) throws SQLException {
        checkClosed();
        try {
            this.mc.setTransactionIsolation(level);
        } catch (SQLException sqlException) {
            checkAndFireConnectionError(sqlException);
        }
    }

    @Override // java.sql.Connection
    public int getTransactionIsolation() throws SQLException {
        checkClosed();
        try {
            return this.mc.getTransactionIsolation();
        } catch (SQLException sqlException) {
            checkAndFireConnectionError(sqlException);
            return 4;
        }
    }

    @Override // java.sql.Connection
    public void setTypeMap(Map map) throws SQLException {
        checkClosed();
        try {
            this.mc.setTypeMap(map);
        } catch (SQLException sqlException) {
            checkAndFireConnectionError(sqlException);
        }
    }

    @Override // java.sql.Connection
    public Map getTypeMap() throws SQLException {
        checkClosed();
        try {
            return this.mc.getTypeMap();
        } catch (SQLException sqlException) {
            checkAndFireConnectionError(sqlException);
            return null;
        }
    }

    @Override // java.sql.Connection
    public SQLWarning getWarnings() throws SQLException {
        checkClosed();
        try {
            return this.mc.getWarnings();
        } catch (SQLException sqlException) {
            checkAndFireConnectionError(sqlException);
            return null;
        }
    }

    @Override // java.sql.Connection
    public void clearWarnings() throws SQLException {
        checkClosed();
        try {
            this.mc.clearWarnings();
        } catch (SQLException sqlException) {
            checkAndFireConnectionError(sqlException);
        }
    }

    @Override // java.sql.Connection, java.lang.AutoCloseable
    public void close() throws SQLException {
        close(true);
    }

    @Override // java.sql.Connection
    public void commit() throws SQLException {
        checkClosed();
        if (isInGlobalTx()) {
            throw SQLError.createSQLException("Can't call commit() on an XAConnection associated with a global transaction", "2D000", 1401);
        }
        try {
            this.mc.commit();
        } catch (SQLException sqlException) {
            checkAndFireConnectionError(sqlException);
        }
    }

    @Override // java.sql.Connection
    public Statement createStatement() throws SQLException {
        checkClosed();
        try {
            return new StatementWrapper(this, this.mpc, this.mc.createStatement());
        } catch (SQLException sqlException) {
            checkAndFireConnectionError(sqlException);
            return null;
        }
    }

    @Override // java.sql.Connection
    public Statement createStatement(int resultSetType, int resultSetConcurrency) throws SQLException {
        checkClosed();
        try {
            return new StatementWrapper(this, this.mpc, this.mc.createStatement(resultSetType, resultSetConcurrency));
        } catch (SQLException sqlException) {
            checkAndFireConnectionError(sqlException);
            return null;
        }
    }

    @Override // java.sql.Connection
    public Statement createStatement(int arg0, int arg1, int arg2) throws SQLException {
        checkClosed();
        try {
            return new StatementWrapper(this, this.mpc, this.mc.createStatement(arg0, arg1, arg2));
        } catch (SQLException sqlException) {
            checkAndFireConnectionError(sqlException);
            return null;
        }
    }

    @Override // java.sql.Connection
    public String nativeSQL(String sql) throws SQLException {
        checkClosed();
        try {
            return this.mc.nativeSQL(sql);
        } catch (SQLException sqlException) {
            checkAndFireConnectionError(sqlException);
            return null;
        }
    }

    @Override // java.sql.Connection
    public CallableStatement prepareCall(String sql) throws SQLException {
        checkClosed();
        try {
            return new CallableStatementWrapper(this, this.mpc, this.mc.prepareCall(sql));
        } catch (SQLException sqlException) {
            checkAndFireConnectionError(sqlException);
            return null;
        }
    }

    @Override // java.sql.Connection
    public CallableStatement prepareCall(String sql, int resultSetType, int resultSetConcurrency) throws SQLException {
        checkClosed();
        try {
            return new CallableStatementWrapper(this, this.mpc, this.mc.prepareCall(sql, resultSetType, resultSetConcurrency));
        } catch (SQLException sqlException) {
            checkAndFireConnectionError(sqlException);
            return null;
        }
    }

    @Override // java.sql.Connection
    public CallableStatement prepareCall(String arg0, int arg1, int arg2, int arg3) throws SQLException {
        checkClosed();
        try {
            return new CallableStatementWrapper(this, this.mpc, this.mc.prepareCall(arg0, arg1, arg2, arg3));
        } catch (SQLException sqlException) {
            checkAndFireConnectionError(sqlException);
            return null;
        }
    }

    public PreparedStatement clientPrepare(String sql) throws SQLException {
        checkClosed();
        try {
            return new PreparedStatementWrapper(this, this.mpc, this.mc.clientPrepareStatement(sql));
        } catch (SQLException sqlException) {
            checkAndFireConnectionError(sqlException);
            return null;
        }
    }

    public PreparedStatement clientPrepare(String sql, int resultSetType, int resultSetConcurrency) throws SQLException {
        checkClosed();
        try {
            return new PreparedStatementWrapper(this, this.mpc, this.mc.clientPrepareStatement(sql, resultSetType, resultSetConcurrency));
        } catch (SQLException sqlException) {
            checkAndFireConnectionError(sqlException);
            return null;
        }
    }

    @Override // java.sql.Connection
    public PreparedStatement prepareStatement(String sql) throws SQLException {
        checkClosed();
        try {
            return new PreparedStatementWrapper(this, this.mpc, this.mc.prepareStatement(sql));
        } catch (SQLException sqlException) {
            checkAndFireConnectionError(sqlException);
            return null;
        }
    }

    @Override // java.sql.Connection
    public PreparedStatement prepareStatement(String sql, int resultSetType, int resultSetConcurrency) throws SQLException {
        checkClosed();
        try {
            return new PreparedStatementWrapper(this, this.mpc, this.mc.prepareStatement(sql, resultSetType, resultSetConcurrency));
        } catch (SQLException sqlException) {
            checkAndFireConnectionError(sqlException);
            return null;
        }
    }

    @Override // java.sql.Connection
    public PreparedStatement prepareStatement(String arg0, int arg1, int arg2, int arg3) throws SQLException {
        checkClosed();
        try {
            return new PreparedStatementWrapper(this, this.mpc, this.mc.prepareStatement(arg0, arg1, arg2, arg3));
        } catch (SQLException sqlException) {
            checkAndFireConnectionError(sqlException);
            return null;
        }
    }

    @Override // java.sql.Connection
    public PreparedStatement prepareStatement(String arg0, int arg1) throws SQLException {
        checkClosed();
        try {
            return new PreparedStatementWrapper(this, this.mpc, this.mc.prepareStatement(arg0, arg1));
        } catch (SQLException sqlException) {
            checkAndFireConnectionError(sqlException);
            return null;
        }
    }

    @Override // java.sql.Connection
    public PreparedStatement prepareStatement(String arg0, int[] arg1) throws SQLException {
        checkClosed();
        try {
            return new PreparedStatementWrapper(this, this.mpc, this.mc.prepareStatement(arg0, arg1));
        } catch (SQLException sqlException) {
            checkAndFireConnectionError(sqlException);
            return null;
        }
    }

    @Override // java.sql.Connection
    public PreparedStatement prepareStatement(String arg0, String[] arg1) throws SQLException {
        checkClosed();
        try {
            return new PreparedStatementWrapper(this, this.mpc, this.mc.prepareStatement(arg0, arg1));
        } catch (SQLException sqlException) {
            checkAndFireConnectionError(sqlException);
            return null;
        }
    }

    @Override // java.sql.Connection
    public void releaseSavepoint(Savepoint arg0) throws SQLException {
        checkClosed();
        try {
            this.mc.releaseSavepoint(arg0);
        } catch (SQLException sqlException) {
            checkAndFireConnectionError(sqlException);
        }
    }

    @Override // java.sql.Connection
    public void rollback() throws SQLException {
        checkClosed();
        if (isInGlobalTx()) {
            throw SQLError.createSQLException("Can't call rollback() on an XAConnection associated with a global transaction", "2D000", 1401);
        }
        try {
            this.mc.rollback();
        } catch (SQLException sqlException) {
            checkAndFireConnectionError(sqlException);
        }
    }

    @Override // java.sql.Connection
    public void rollback(Savepoint arg0) throws SQLException {
        checkClosed();
        if (isInGlobalTx()) {
            throw SQLError.createSQLException("Can't call rollback() on an XAConnection associated with a global transaction", "2D000", 1401);
        }
        try {
            this.mc.rollback(arg0);
        } catch (SQLException sqlException) {
            checkAndFireConnectionError(sqlException);
        }
    }

    public boolean isSameResource(Connection c) {
        if (c instanceof ConnectionWrapper) {
            return this.mc.isSameResource(((ConnectionWrapper) c).mc);
        }
        if (c instanceof com.mysql.jdbc.Connection) {
            return this.mc.isSameResource((com.mysql.jdbc.Connection) c);
        }
        return false;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void close(boolean fireClosedEvent) throws SQLException {
        synchronized (this.mpc) {
            if (this.closed) {
                return;
            }
            if (!isInGlobalTx() && this.mc.getRollbackOnPooledClose() && !getAutoCommit()) {
                rollback();
            }
            if (fireClosedEvent) {
                this.mpc.callListener(2, null);
            }
            this.closed = true;
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void checkClosed() throws SQLException {
        if (this.closed) {
            throw SQLError.createSQLException(this.invalidHandleStr);
        }
    }

    protected boolean isInGlobalTx() {
        return this.mc.isInGlobalTx();
    }

    protected void setInGlobalTx(boolean flag) {
        this.mc.setInGlobalTx(flag);
    }

    public void ping() throws SQLException {
        if (this.mc != null) {
            this.mc.ping();
        }
    }
}
